<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-paquet-xml-bigup?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// B
	'bigup_description' => 'تنزيل المستندات بالسحب والرمي',
	'bigup_nom' => 'تحميل كبير',
	'bigup_slogan' => 'تحميل الملفات مهما كان حجمها',
];
